@@ -6,14 +6,16 @@ BW2stagePPSe <- function(Ni, ni, X, psuID, w, m, pp){
 
     S2i <- by(X, INDICES = psuID, FUN = var)
     Vi <- Ni * (Ni/ni - 1) * S2i
-    F2 <- sum( (1-pi.star )/pi.star^2 * Vi )
+#    F2 <- sum( (1-pi.star )/pi.star^2 * Vi ) # used in v.0.7 and earlier
+    F2 <- sum(Vi /pp^2) / m^2
     F1 <- by(w*X, psuID, sum)
     v1 <- m * var(F1)
 
     Vpsu <- v1 - F2
     Vssu <- sum(Vi / (pi.star)^2)
 
-    B <- (m*v1 - sum((1-pi.star)*Vi / m / pp^2)) / t.pwr^2
+#    B <- (m*v1 - sum((1-pi.star)*Vi / m / pp^2)) / t.pwr^2 # used in v.0.7 and earlier
+    B <-  m*Vpsu / t.pwr^2
     W <- sum(Ni^2 * S2i / m / pp^2) / t.pwr^2
     delta <- B / (B + W)
 
